#' @title Put Rho
#' @description Calculate the Rho (Option Greek) of Option Contract
#' @param s Spot Price of Underlying Asset
#' @param k Exercise Price of Contract
#' @param t Time to Expiration
#' @param sd Volatality
#' @param r Risk free rate of return
#' @param d Divident Yield (use cont.rate()), Default: 0
#' @return Output gives the Estimated Premium of a Option Contract.
#' @details Rho represents the rate of change between an option's value and a 1% change in the interest rate.
#' @examples
#' put.rho(100, 105, 0.25, 0.35, 0.0488)
#' @rdname put.rho
#' @export
#' @importFrom purrr map_dbl
#' @import ggplot2
#' @importFrom plotly ggplotly
#' @importFrom stats pnorm
put.rho = function(s, k, t, sd, r, d = 0){
  d1 = (log(s/k) + (r - d + (sd^2)/2) * t) / (sd * sqrt(t))
  d2 = d1 - (sd * sqrt(t))
  nd1 = pnorm(d1)
  nd2 = pnorm(d2)
  Rho = -1 * (k * t * exp(-1 * r * t) * pnorm(-d2))
  data.frame(put.rho = Rho)
}
